using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;

namespace RumbleComponentExample
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        Texture2D ball;
        Vector2 position;
        Vector2 speed;

        Rumble rumble;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            //Create the rumble component.
            rumble = new Rumble(this);
            Components.Add(rumble);
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            ball = Content.Load<Texture2D>("ball1");

            //Start the ball at the center.
            position = new Vector2(
                (GraphicsDevice.Viewport.Width - ball.Width) / 2.0f,
                (GraphicsDevice.Viewport.Height - ball.Height) / 2.0f);

            //Ball movement control.
            speed = new Vector2(100, 100);
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //Move the ball
            position += speed * (float)gameTime.ElapsedGameTime.TotalSeconds;

            //Bounce the ball in the opposite direction when it hits a wall.
            if (position.X <= 0 || position.X + ball.Width >= GraphicsDevice.Viewport.Width)
            {
                speed.X *= -1;
                rumble.AddRumble(PlayerIndex.One, 1.0f, 0.5f, 0.3f, Rumble.Shape.ExponentialInvert);
            }
            if (position.Y <= 0 || position.Y + ball.Height >= GraphicsDevice.Viewport.Height)
            {
                speed.Y *= -1;
                rumble.AddRumble(PlayerIndex.One, 1.0f, 0.5f, 0.3f, Rumble.Shape.Parabolic);
            }

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            spriteBatch.Begin();
            spriteBatch.Draw(ball, position, Color.White);
            spriteBatch.End();


            base.Draw(gameTime);
        }
    }
}
